from typing import Literal

BreakBefore = Literal[
    'auto',
    'avoid',
    'all',
    'avoid-page',
    'page',
    'left',
    'right',
    'column',
]
